@@ -22,7 +22,10 @@ from .core import (
     assess_image_quality,
     analyze_image_features,
     analyze_encoding_needs,
-    apply_smart_encoding
+    apply_smart_encoding,
+    apply_encoding,
+    apply_encoding_with_encoders,
+    summarize_eda_insights
 )
 
 __all__ = [
@@ -43,5 +46,8 @@ __all__ = [
     'assess_image_quality',
     'analyze_image_features',
     'analyze_encoding_needs',
-    'apply_smart_encoding'
+    'apply_smart_encoding',
+    'apply_encoding',
+    'apply_encoding_with_encoders',
+    'summarize_eda_insights'
 ]
